@@ -4,7 +4,7 @@ from typing import List
 
 import numpy as np
 
-from osef.constants import LidarModel
+from osef import constants
 
 
 def _get_value_packer(pack_format: str):
@@ -15,7 +15,7 @@ def _get_value_packer(pack_format: str):
 
 
 def _array_packer(value: np.array) -> bytes:
-    return value.tobytes()
+    return value.tobytes("F")
 
 
 def _bytes_packer(value: bytes) -> bytes:
@@ -113,7 +113,7 @@ def _imu_packer(value: dict) -> bytes:
     )
 
 
-def _lidar_model_packer(value: LidarModel):
+def _lidar_model_packer(value: constants.LidarModel):
     if len(value) == 0:
         return bytes()
     return Struct("<B").pack(value.id)
