@@ -4,12 +4,8 @@ from typing import List
 
 import numpy as np
 
-from osef.constants import (
-    LidarModel,
-    PerceptIds,
-    TrackedObjectClassIds,
-    LidarModelIds,
-)
+from osef import constants
+from osef import osef_types
 
 
 def _get_value_unpacker(pack_format: str):
@@ -19,9 +15,12 @@ def _get_value_unpacker(pack_format: str):
     return _parse_value
 
 
-def _get_array_unpacker(dtype: np.dtype):
+def _get_array_unpacker(dtype: np.dtype, rows: int = 1):
     def _parse_array(value: bytes) -> np.ndarray:
-        return np.frombuffer(value, dtype=dtype)
+        array = np.frombuffer(value, dtype=dtype)
+        if rows > 1:
+            array = np.reshape(array, (rows, int(array.shape[0] / rows)), order="F")
+        return array
 
     return _parse_array
 
@@ -77,7 +76,7 @@ def _percept_class_unpacker(value: bytes) -> np.ndarray:
 
     classes_iter = Struct("<H").iter_unpack(value)
 
-    data_list = [(code[0], PerceptIds(code[0]).name) for code in classes_iter]
+    data_list = [(code[0], osef_types.PerceptId(code[0]).name) for code in classes_iter]
     return np.array(data_list, dtype=dtype)
 
 
@@ -87,19 +86,19 @@ def _class_array_unpacker(value: bytes) -> np.ndarray:
         return np.array([], dtype=dtype)
 
     classes_iter = Struct("<L").iter_unpack(value)
-    data_list = [
-        (code[0], TrackedObjectClassIds(code[0]).name) for code in classes_iter
-    ]
+    data_list = [(code[0], osef_types.ClassId(code[0]).name) for code in classes_iter]
     return np.array(data_list, dtype=dtype)
 
 
-def _lidar_model_unpacker(value: bytes) -> LidarModel:
+def _lidar_model_unpacker(value: bytes) -> constants.LidarModel:
 
     if len(value) == 0:
-        return LidarModel(0, LidarModelIds.UNKNOWN.name)
+        return constants.LidarModel(0, osef_types.LidarModelId.UNKNOWN.name)
 
     model_code = Struct("<B").unpack(value)[0]
-    data_list = LidarModel(model_code, LidarModelIds(model_code).name)
+    data_list = constants.LidarModel(
+        model_code, osef_types.LidarModelId(model_code).name
+    )
     return data_list
 
 
