@@ -82,6 +82,11 @@ class OsefStream:
                 tcp_socket.connect(
                     (self._parsed_path.hostname, self._parsed_path.port or 11120)
                 )
+                osef_logger.warning(
+                    "Connected to %s:%d",
+                    self._parsed_path.hostname,
+                    self._parsed_path.port,
+                )
                 break
             except ConnectionRefusedError:
                 error_string = "Connection refused."
